summaryrefslogtreecommitdiffstats
path: root/base/tps/src/org/dogtagpki/server/tps/rest
diff options
context:
space:
mode:
authorEndi S. Dewata <edewata@redhat.com>2016-04-23 05:28:10 +0200
committerEndi S. Dewata <edewata@redhat.com>2016-05-03 01:57:34 +0200
commit1b8f5230d01499d97b874d4912c5c1a13e389c5f (patch)
tree761b0f7d2b2de2e58862fe81af1bee219e078f47 /base/tps/src/org/dogtagpki/server/tps/rest
parent0b779ffe4d29474b4f75370e4da9d7723d9bfec5 (diff)
downloadpki-1b8f5230d01499d97b874d4912c5c1a13e389c5f.tar.gz
pki-1b8f5230d01499d97b874d4912c5c1a13e389c5f.tar.xz
pki-1b8f5230d01499d97b874d4912c5c1a13e389c5f.zip
Renamed token status UNINITIALIZED to READY.
The token status UNINITIALIZED has been renamed to READY for clarity. To simplify the transition, the CLIs and the REST API will continue to accept UNINITIALIZED but it will be converted internally into READY and a deprecation warning will be generated. https://fedorahosted.org/pki/ticket/2288
Diffstat (limited to 'base/tps/src/org/dogtagpki/server/tps/rest')
-rw-r--r--base/tps/src/org/dogtagpki/server/tps/rest/TokenService.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/base/tps/src/org/dogtagpki/server/tps/rest/TokenService.java b/base/tps/src/org/dogtagpki/server/tps/rest/TokenService.java
index cc68c8ad3..441518e8b 100644
--- a/base/tps/src/org/dogtagpki/server/tps/rest/TokenService.java
+++ b/base/tps/src/org/dogtagpki/server/tps/rest/TokenService.java
@@ -91,9 +91,9 @@ public class TokenService extends PKIService implements TokenResource {
auditModParams.put("UserID", tokenRecord.getUserID());
switch (tokenState.getValue()) {
- case TokenStatus.TOKEN_UNINITIALIZED:
- tokenRecord.setStatus("uninitialized");
- newStatus = "uninitialized";
+ case TokenStatus.TOKEN_READY:
+ tokenRecord.setStatus("ready");
+ newStatus = "ready";
tokenRecord.setReason(null);
break;
@@ -377,9 +377,9 @@ public class TokenService extends PKIService implements TokenResource {
auditModParams.put("Policy", policy);
}
- // new tokens are uninitialized when created
- tokenRecord.setStatus("uninitialized");
- auditModParams.put("Status", "uninitialized");
+ // new tokens are ready when created
+ tokenRecord.setStatus("ready");
+ auditModParams.put("Status", "ready");
database.addRecord(tokenID, tokenRecord);
subsystem.tdb.tdbActivity(ActivityDatabase.OP_ADD, tokenRecord,